Module: Rack
- Defined in:
- lib/rack/adapter/rails.rb,
lib/rack/handler/grizzly.rb,
lib/rack/handler/glassfish.rb
Overview
Based on http://github.com/macournoyer/thin/tree/master/lib/rack/adapter/rails.rb Adapter to run a Rails app with any supported Rack handler. By default it will try to load the Rails application in the current directory in the development environment. Options: root: Root directory of the Rails app env: Rails environment to run in (development, production or test) Based on http://fuzed.rubyforge.org/ Rails adapter